@@ -16,7 +16,6 @@ DNA_COMP = str.maketrans("ACGTacgt", "TGCAtgca")
 
 
 class Alignment:
-
     def __init__(self, score=0, attributes=None, species_to_lengths=None):
         # species_to_lengths is needed only for file formats that don't provide
         # chromosome lengths;  it maps each species name to one of these:
@@ -58,6 +57,7 @@ class Alignment:
                 except ValueError:
                     pass
         self.__score = score
+
     score = property(fget=get_score, fset=set_score)
 
     def __str__(self):
@@ -79,7 +79,7 @@ class Alignment:
             chrom_to_length = self.species_to_lengths
         else:
             raise ValueError("no src_size (no length file for %s)" % species)
-        if isinstance(chrom_to_length, int):         # (if it's a single length)
+        if isinstance(chrom_to_length, int):  # (if it's a single length)
             return chrom_to_length
         if isinstance(chrom_to_length, str):  # (if it's a file name)
             chrom_to_length = read_lengths_file(chrom_to_length)
@@ -141,7 +141,7 @@ class Alignment:
             raise ValueError("can't figure out what to do")
         start_col = ref.coord_to_col(start)
         end_col = ref.coord_to_col(end)
-        if ref.strand == '-':
+        if ref.strand == "-":
             (start_col, end_col) = (end_col, start_col)
         return self.slice(start_col, end_col)
 
@@ -156,7 +156,7 @@ class Alignment:
         new = Alignment(score=self.score, attributes=self.attributes)
         new.text_size = self.text_size
         for component in self.components:
-            if component.src.split('.')[0] in species:
+            if component.src.split(".")[0] in species:
                 new.add_component(component)
         return new
 
@@ -180,7 +180,7 @@ class Alignment:
             for seq in seqs:
                 if seq is None:
                     continue
-                if seq[i] != '-':
+                if seq[i] != "-":
                     all_gap = False
             if all_gap:
                 for seq in seqs:
@@ -193,7 +193,7 @@ class Alignment:
         for i in range(len(self.components)):
             if seqs[i] is None:
                 continue
-            self.components[i].text = ''.join(seqs[i])
+            self.components[i].text = "".join(seqs[i])
         self.text_size = text_size
 
     def __eq__(self, other):
@@ -211,25 +211,29 @@ class Alignment:
         return True
 
     def __ne__(self, other):
-        return not(self.__eq__(other))
+        return not (self.__eq__(other))
 
     def __deepcopy__(self, memo):
         from copy import deepcopy
-        new = Alignment(score=self.score, attributes=deepcopy(self.attributes), species_to_lengths=deepcopy(self.species_to_lengths))
+
+        new = Alignment(
+            score=self.score, attributes=deepcopy(self.attributes), species_to_lengths=deepcopy(self.species_to_lengths)
+        )
         for component in self.components:
             new.add_component(deepcopy(component))
         return new
 
 
 class Component:
-
-    def __init__(self, src='', start=0, size=0, strand=None, src_size=None, text=''):
+    def __init__(self, src="", start=0, size=0, strand=None, src_size=None, text=""):
         self._alignment = None
         self.src = src
-        self.start = start          # Nota Bene:  start,size,strand are as they
-        self.size = size            # .. appear in a MAF file-- origin-zero, end
-        self.strand = strand        # .. excluded, and minus strand counts from
-        self._src_size = src_size   # .. end of sequence
+        # Nota Bene: start, size, strand are as they appear in a MAF file:
+        # origin-zero, end excluded, and minus strand counts from end of sequence
+        self.start = start
+        self.size = size
+        self.strand = strand
+        self._src_size = src_size
         self.text = text
         self.quality = None
         # Optional fields to keep track of synteny status (only makes sense
@@ -246,18 +250,28 @@ class Component:
     def __str__(self):
         if self.empty:
             rval = "e %s %d %d %s %d %s" % (
-                self.src, self.start, self.size, self.strand, self.src_size, self.synteny_empty)
+                self.src,
+                self.start,
+                self.size,
+                self.strand,
+                self.src_size,
+                self.synteny_empty,
+            )
         else:
-            rval = "s %s %d %d %s %d %s" % (
-                self.src, self.start, self.size, self.strand, self.src_size, self.text)
+            rval = "s %s %d %d %s %d %s" % (self.src, self.start, self.size, self.strand, self.src_size, self.text)
             if self.synteny_left and self.synteny_right:
                 rval += "\ni %s %s %d %s %d" % (
-                    self.src, self.synteny_left[0], self.synteny_left[1],
-                    self.synteny_right[0], self.synteny_right[1])
+                    self.src,
+                    self.synteny_left[0],
+                    self.synteny_left[1],
+                    self.synteny_right[0],
+                    self.synteny_right[1],
+                )
         return rval
 
     def get_end(self):
         return self.start + self.size
+
     end = property(fget=get_end)
 
     def get_src_size(self):
@@ -269,20 +283,23 @@ class Component:
 
     def set_src_size(self, src_size):
         self._src_size = src_size
+
     src_size = property(fget=get_src_size, fset=set_src_size)
 
     def get_forward_strand_start(self):
-        if self.strand == '-':
+        if self.strand == "-":
             return self.src_size - self.end
         else:
             return self.start
+
     forward_strand_start = property(fget=get_forward_strand_start)
 
     def get_forward_strand_end(self):
-        if self.strand == '-':
+        if self.strand == "-":
             return self.src_size - self.start
         else:
             return self.end
+
     forward_strand_end = property(fget=get_forward_strand_end)
 
     def reverse_complement(self):
@@ -324,8 +341,8 @@ class Component:
         #    if self.text[i] != '-': new.start += 1
         # for c in new.text:
         #    if c != '-': new.size += 1
-        new.start += start - self.text.count('-', 0, start)
-        new.size = len(new.text) - new.text.count('-')
+        new.start += start - self.text.count("-", 0, start)
+        new.size = len(new.text) - new.text.count("-")
 
         # FIXME: This annotation probably means nothing after slicing if
         # one of the ends changes. In general the 'i' rows of a MAF only
@@ -351,7 +368,7 @@ class Component:
         """
         start_col = self.coord_to_col(start)
         end_col = self.coord_to_col(end)
-        if (self.strand == '-'):
+        if self.strand == "-":
             (start_col, end_col) = (end_col, start_col)
         return self.slice(start_col, end_col)
 
@@ -369,18 +386,18 @@ class Component:
             raise ValueError("Range error: %d not in %d-%d" % (pos, start, end))
         if not self.index:
             self.index = list()
-            if self.strand == '-':
+            if self.strand == "-":
                 # nota bene: for - strand self.index[x] maps to one column
                 # higher than is actually associated with the position;  thus
                 # when slice_by_component() and slice_by_coord() flip the ends,
                 # the resulting slice is correct
-                for x in range(len(self.text)-1, -1, -1):
-                    if not self.text[x] == '-':
+                for x in range(len(self.text) - 1, -1, -1):
+                    if not self.text[x] == "-":
                         self.index.append(x + 1)
                 self.index.append(0)
             else:
                 for x in range(len(self.text)):
-                    if not self.text[x] == '-':
+                    if not self.text[x] == "-":
                         self.index.append(x)
                 self.index.append(len(self.text))
         x = None
@@ -393,22 +410,26 @@ class Component:
     def __eq__(self, other):
         if other is None or not isinstance(other, type(self)):
             return False
-        return (self.src == other.src
-                and self.start == other.start
-                and self.size == other.size
-                and self.strand == other.strand
-                and self._src_size == other._src_size
-                and self.text == other.text
-                and self.synteny_left == other.synteny_left
-                and self.synteny_right == other.synteny_right
-                and self.synteny_empty == other.synteny_empty
-                and self.empty == other.empty)
+        return (
+            self.src == other.src
+            and self.start == other.start
+            and self.size == other.size
+            and self.strand == other.strand
+            and self._src_size == other._src_size
+            and self.text == other.text
+            and self.synteny_left == other.synteny_left
+            and self.synteny_right == other.synteny_right
+            and self.synteny_empty == other.synteny_empty
+            and self.empty == other.empty
+        )
 
     def __ne__(self, other):
-        return not(self.__eq__(other))
+        return not (self.__eq__(other))
 
     def __deepcopy__(self, memo):
-        new = Component(src=self.src, start=self.start, size=self.size, strand=self.strand, src_size=self._src_size, text=self.text)
+        new = Component(
+            src=self.src, start=self.start, size=self.size, strand=self.strand, src_size=self._src_size, text=self.text
+        )
         new._alignment = self._alignment
         new.quality = self.quality
         new.synteny_left = self.synteny_left
@@ -423,6 +444,7 @@ def get_reader(format, infile, species_to_lengths=None):
     import bx.align.axt
     import bx.align.lav
     import bx.align.maf
+
     if format == "maf":
         return bx.align.maf.Reader(infile, species_to_lengths)
     elif format == "axt":
@@ -437,6 +459,7 @@ def get_writer(format, outfile, attributes=None):
     import bx.align.axt
     import bx.align.lav
     import bx.align.maf
+
     if attributes is None:
         attributes = {}
     if format == "maf":
@@ -453,6 +476,7 @@ def get_indexed(format, filename, index_filename=None, keep_open=False, species_
     import bx.align.axt
     import bx.align.lav
     import bx.align.maf
+
     if format == "maf":
         return bx.align.maf.Indexed(filename, index_filename, keep_open, species_to_lengths)
     elif format == "axt":
@@ -469,7 +493,7 @@ def shuffle_columns(a):
     random.shuffle(mask)
     for c in a.components:
         if not c.empty:
-            c.text = ''.join([c.text[i] for i in mask])
+            c.text = "".join(c.text[i] for i in mask)
 
 
 def src_split(src):  # splits src into species,chrom
@@ -477,7 +501,7 @@ def src_split(src):  # splits src into species,chrom
     if dot == -1:
         return None, src
     else:
-        return src[:dot], src[dot+1:]
+        return src[:dot], src[dot + 1 :]
 
 
 def src_merge(species, chrom, contig=None):  # creates src (inverse of src_split)
@@ -489,16 +513,18 @@ def src_merge(species, chrom, contig=None):  # creates src (inverse of src_split
         src += "[%s]" % contig
     return src
 
+
 # ---- Read C extension if available ---------------------------------------
 
 
 try:
     from ._core import coord_to_col
 except ImportError:
+
     def coord_to_col(start, text, pos):
         col = 0
         while start < pos:
-            if text[col] != '-':
+            if text[col] != "-":
                 start += 1
             col += 1
         return col
