@@ -14,7 +14,7 @@ def chop_list(blocks, src, start, end):
     for block in blocks:
         ref = block.get_component_by_src(src)
         # If the reference component is on the '-' strand we should complement the interval
-        if ref.strand == '-':
+        if ref.strand == "-":
             slice_start = max(ref.src_size - end, ref.start)
             slice_end = max(ref.src_size - start, ref.end)
         else:
