@@ -6,7 +6,7 @@ Merge overlapping regions in two sets of genomic intervals.
 from bx.intervals.io import BitsetSafeReaderWrapper
 from bx.intervals.operations import (
     bits_set_in_range,
-    MAX_END
+    MAX_END,
 )
 
 
