@@ -6,7 +6,7 @@ import bz2
 import gzip
 
 
-def open_compressed(filename, mode='r'):
+def open_compressed(filename, mode="r"):
     if filename.endswith(".bz2"):
         return bz2.BZ2File(filename, mode)
     elif filename.endswith(".gz"):
