@@ -3,8 +3,7 @@ from io import StringIO
 
 import bx.pwm.position_weight_matrix as pwm
 
-basicPwm = \
-    """>MA0101 c-REL REL
+basicPwm = """>MA0101 c-REL REL
 0   5   8   4
 0   1   15  1
 1   0   15  1
@@ -17,8 +16,7 @@ basicPwm = \
 1   16  0   0
 """
 
-transfacPwm = \
-    """ID  TATA
+transfacPwm = """ID  TATA
 XX
 P0    A    C    G    T
 01   33   73   78   16      S
@@ -39,40 +37,48 @@ P0    A    C    G    T
 XX
 """
 
-background = {'A': .28, 'C': .21, 'G': .24, 'T': .27}
+background = {"A": 0.28, "C": 0.21, "G": 0.24, "T": 0.27}
 
 dSeq = "ACCGAGTTAGCGTAAA"
 dScoresExpected = "-15.3697 0.4240 -16.5309 0.4027"
 
-qSeq = [{'A': 0.27, 'C': 0.34, 'G': 0.07, 'T': 0.32},
-        {'A': 0.24, 'C': 0.32, 'G': 0.09, 'T': 0.35},
-        {'A': 0.80, 'C': 0.11, 'G': 0.03, 'T': 0.06},
-        {'A': 0.07, 'C': 0.22, 'G': 0.37, 'T': 0.34},
-        {'A': 0.07, 'C': 0.44, 'G': 0.03, 'T': 0.46},
-        {'A': 0.43, 'C': 0.04, 'G': 0.18, 'T': 0.35},
-        {'A': 0.84, 'C': 0.14, 'G': 0.01, 'T': 0.01},
-        {'A': 0.31, 'C': 0.52, 'G': 0.13, 'T': 0.04},
-        {'A': 0.22, 'C': 0.22, 'G': 0.45, 'T': 0.11},
-        {'A': 0.36, 'C': 0.15, 'G': 0.42, 'T': 0.07},
-        {'A': 0.11, 'C': 0.78, 'G': 0.07, 'T': 0.04},
-        {'A': 0.07, 'C': 0.16, 'G': 0.64, 'T': 0.13},
-        {'A': 0.34, 'C': 0.59, 'G': 0.03, 'T': 0.04},
-        {'A': 0.32, 'C': 0.15, 'G': 0.07, 'T': 0.46},
-        {'A': 0.07, 'C': 0.03, 'G': 0.59, 'T': 0.31}]
+qSeq = [
+    {"A": 0.27, "C": 0.34, "G": 0.07, "T": 0.32},
+    {"A": 0.24, "C": 0.32, "G": 0.09, "T": 0.35},
+    {"A": 0.80, "C": 0.11, "G": 0.03, "T": 0.06},
+    {"A": 0.07, "C": 0.22, "G": 0.37, "T": 0.34},
+    {"A": 0.07, "C": 0.44, "G": 0.03, "T": 0.46},
+    {"A": 0.43, "C": 0.04, "G": 0.18, "T": 0.35},
+    {"A": 0.84, "C": 0.14, "G": 0.01, "T": 0.01},
+    {"A": 0.31, "C": 0.52, "G": 0.13, "T": 0.04},
+    {"A": 0.22, "C": 0.22, "G": 0.45, "T": 0.11},
+    {"A": 0.36, "C": 0.15, "G": 0.42, "T": 0.07},
+    {"A": 0.11, "C": 0.78, "G": 0.07, "T": 0.04},
+    {"A": 0.07, "C": 0.16, "G": 0.64, "T": 0.13},
+    {"A": 0.34, "C": 0.59, "G": 0.03, "T": 0.04},
+    {"A": 0.32, "C": 0.15, "G": 0.07, "T": 0.46},
+    {"A": 0.07, "C": 0.03, "G": 0.59, "T": 0.31},
+]
 
 qScoresExpected = "4.1106 0.7810"
 
 
-class PWMTestCase (unittest.TestCase):
-
+class PWMTestCase(unittest.TestCase):
     def testReader(self):
 
         # test basic format: i.e. for jaspar
-        wms = [wm for wm in pwm.Reader(StringIO(basicPwm), format="basic", background=background, score_correction=False)]
+        wms = [
+            wm for wm in pwm.Reader(StringIO(basicPwm), format="basic", background=background, score_correction=False)
+        ]
         assert len(wms) == 1
 
         # test transfac format
-        wms = [wm for wm in pwm.Reader(StringIO(transfacPwm), format="transfac", background=background, score_correction=False)]
+        wms = [
+            wm
+            for wm in pwm.Reader(
+                StringIO(transfacPwm), format="transfac", background=background, score_correction=False
+            )
+        ]
         assert len(wms) == 1
 
         wm = wms[0]
