@@ -10,20 +10,21 @@ test_fa = "test_data/seq_tests/test.fa"
 
 # Same sequence data as stored in test.fa
 
-valid_seq = "TGGAGGCATTTGTGATTCAATAGATGCAGAAAGAAACCTTCCTAGAGCTG" \
-    + "GCGTTCTCTAACTAAAAGTGGAAAGTTCTGAGGAATGAGGACTGTTATAA" \
-    + "ATCCCACCCCACACCGCACCTTCTCCAGGGAAGTTTCATGGCCGTGAAGA" \
-    + "GGACAGAAAGTGAGAACCAAGATggaactgaataaacaagcttcacactg" \
-    + "ttagtttccccatatgcttaccttcccacagatgccaaccttggaggcct" \
-    + "aagaggcctagaatattatcctttgtctgatcatttctctacaaatttat" \
-    + "tgttctttgttaagatgctacataagcccaaattctaaccacccctttga" \
+valid_seq = (
+    "TGGAGGCATTTGTGATTCAATAGATGCAGAAAGAAACCTTCCTAGAGCTG"
+    + "GCGTTCTCTAACTAAAAGTGGAAAGTTCTGAGGAATGAGGACTGTTATAA"
+    + "ATCCCACCCCACACCGCACCTTCTCCAGGGAAGTTTCATGGCCGTGAAGA"
+    + "GGACAGAAAGTGAGAACCAAGATggaactgaataaacaagcttcacactg"
+    + "ttagtttccccatatgcttaccttcccacagatgccaaccttggaggcct"
+    + "aagaggcctagaatattatcctttgtctgatcatttctctacaaatttat"
+    + "tgttctttgttaagatgctacataagcccaaattctaaccacccctttga"
     + "gttacccatcatcaagtttctcccatgtg"
+)
 
 valid_seq_len = len(valid_seq)
 
 
 class FASTATestCase(unittest.TestCase):
-
     def test_get(self):
         fastafile = fasta.FastaFile(open(test_fa, "rb"))
         check_get(fastafile, 0, valid_seq_len)
@@ -32,4 +33,4 @@ class FASTATestCase(unittest.TestCase):
 
 
 def check_get(fastafile, start, len):
-    assert fastafile.get(start, len) == valid_seq[start:start+len]
+    assert fastafile.get(start, len) == valid_seq[start : start + len]
