@@ -31,26 +31,27 @@ ident = "$Id: fpconst.py,v 1.12 2004/05/22 04:38:17 warnes Exp $"
 
 
 # check endianess
-_big_endian = struct.pack('i', 1)[:1] != b'\x01'
+_big_endian = struct.pack("i", 1)[:1] != b"\x01"
 
 # and define appropriate constants
-if(_big_endian):
-    NaN = struct.unpack('d', b'\x7F\xF8\x00\x00\x00\x00\x00\x00')[0]
-    PosInf = struct.unpack('d', b'\x7F\xF0\x00\x00\x00\x00\x00\x00')[0]
+if _big_endian:
+    NaN = struct.unpack("d", b"\x7F\xF8\x00\x00\x00\x00\x00\x00")[0]
+    PosInf = struct.unpack("d", b"\x7F\xF0\x00\x00\x00\x00\x00\x00")[0]
     NegInf = -PosInf
 else:
-    NaN = struct.unpack('d', b'\x00\x00\x00\x00\x00\x00\xf8\xff')[0]
-    PosInf = struct.unpack('d', b'\x00\x00\x00\x00\x00\x00\xf0\x7f')[0]
+    NaN = struct.unpack("d", b"\x00\x00\x00\x00\x00\x00\xf8\xff")[0]
+    PosInf = struct.unpack("d", b"\x00\x00\x00\x00\x00\x00\xf0\x7f")[0]
     NegInf = -PosInf
 
 
 def _double_as_bytes(dval):
     "Use struct.unpack to decode a double precision float into eight bytes"
-    tmp = list(struct.unpack('8B', struct.pack('d', dval)))
+    tmp = list(struct.unpack("8B", struct.pack("d", dval)))
     if not _big_endian:
         tmp.reverse()
     return tmp
 
+
 ##
 # Functions to extract components of the IEEE 754 floating point format
 ##
@@ -71,7 +72,7 @@ def _exponent(dval):
     by subtracting 1023 from the value returned by this function
     """
     bb = _double_as_bytes(dval)
-    return (bb[0] << 4 | bb[1] >> 4) & 0x7ff
+    return (bb[0] << 4 | bb[1] >> 4) & 0x7FF
 
 
 def _mantissa(dval):
@@ -79,7 +80,7 @@ def _mantissa(dval):
     point value."""
 
     bb = _double_as_bytes(dval)
-    mantissa = bb[1] & 0x0f << 48
+    mantissa = bb[1] & 0x0F << 48
     mantissa += bb[2] << 40
     mantissa += bb[3] << 32
     mantissa += bb[4]
@@ -90,7 +91,8 @@ def _zero_mantissa(dval):
     """Determine whether the mantissa bits of the given double are all
     zero."""
     bb = _double_as_bytes(dval)
-    return ((bb[1] & 0x0f) | reduce(operator.or_, bb[2:])) == 0
+    return ((bb[1] & 0x0F) | reduce(operator.or_, bb[2:])) == 0
+
 
 ##
 # Functions to test for IEEE 754 special values
@@ -99,31 +101,30 @@ def _zero_mantissa(dval):
 
 def isNaN(value):
     "Determine if the argument is a IEEE 754 NaN (Not a Number) value."
-    return (_exponent(value) == 0x7ff and not _zero_mantissa(value))
+    return _exponent(value) == 0x7FF and not _zero_mantissa(value)
 
 
 def isInf(value):
     """Determine if the argument is an infinite IEEE 754 value (positive
     or negative inifinity)"""
-    return (_exponent(value) == 0x7ff and _zero_mantissa(value))
+    return _exponent(value) == 0x7FF and _zero_mantissa(value)
 
 
 def isFinite(value):
     """Determine if the argument is an finite IEEE 754 value (i.e., is
     not NaN, positive or negative inifinity)"""
-    return (_exponent(value) != 0x7ff)
+    return _exponent(value) != 0x7FF
 
 
 def isPosInf(value):
     "Determine if the argument is a IEEE 754 positive infinity value"
-    return (_sign(value) == 0 and _exponent(value) == 0x7ff
-            and _zero_mantissa(value))
+    return _sign(value) == 0 and _exponent(value) == 0x7FF and _zero_mantissa(value)
 
 
 def isNegInf(value):
     "Determine if the argument is a IEEE 754 negative infinity value"
-    return (_sign(value) == 1 and _exponent(value) == 0x7ff
-            and _zero_mantissa(value))
+    return _sign(value) == 1 and _exponent(value) == 0x7FF and _zero_mantissa(value)
+
 
 ##
 # Functions to test public functions.
@@ -131,43 +132,44 @@ def isNegInf(value):
 
 
 def test_isNaN():
-    assert(not isNaN(PosInf))
-    assert(not isNaN(NegInf))
-    assert(isNaN(NaN))
-    assert(not isNaN(1.0))
-    assert(not isNaN(-1.0))
+    assert not isNaN(PosInf)
+    assert not isNaN(NegInf)
+    assert isNaN(NaN)
+    assert not isNaN(1.0)
+    assert not isNaN(-1.0)
 
 
 def test_isInf():
-    assert(isInf(PosInf))
-    assert(isInf(NegInf))
-    assert(not isInf(NaN))
-    assert(not isInf(1.0))
-    assert(not isInf(-1.0))
+    assert isInf(PosInf)
+    assert isInf(NegInf)
+    assert not isInf(NaN)
+    assert not isInf(1.0)
+    assert not isInf(-1.0)
 
 
 def test_isFinite():
-    assert(not isFinite(PosInf))
-    assert(not isFinite(NegInf))
-    assert(not isFinite(NaN))
-    assert(isFinite(1.0))
-    assert(isFinite(-1.0))
+    assert not isFinite(PosInf)
+    assert not isFinite(NegInf)
+    assert not isFinite(NaN)
+    assert isFinite(1.0)
+    assert isFinite(-1.0)
 
 
 def test_isPosInf():
-    assert(isPosInf(PosInf))
-    assert(not isPosInf(NegInf))
-    assert(not isPosInf(NaN))
-    assert(not isPosInf(1.0))
-    assert(not isPosInf(-1.0))
+    assert isPosInf(PosInf)
+    assert not isPosInf(NegInf)
+    assert not isPosInf(NaN)
+    assert not isPosInf(1.0)
+    assert not isPosInf(-1.0)
 
 
 def test_isNegInf():
-    assert(not isNegInf(PosInf))
-    assert(isNegInf(NegInf))
-    assert(not isNegInf(NaN))
-    assert(not isNegInf(1.0))
-    assert(not isNegInf(-1.0))
+    assert not isNegInf(PosInf)
+    assert isNegInf(NegInf)
+    assert not isNegInf(NaN)
+    assert not isNegInf(1.0)
+    assert not isNegInf(-1.0)
+
 
 # overall test
 
