@@ -29,7 +29,7 @@ import bx.align.maf
 
 def usage(s=None):
     message = __doc__
-    if (s is None):
+    if s is None:
         sys.exit(message)
     else:
         sys.exit(f"{s}\n{message}")
@@ -49,14 +49,14 @@ def main():
     # pick off options
 
     args = sys.argv[1:]
-    while (len(args) > 0):
+    while len(args) > 0:
         arg = args.pop(0)
         val = None
         fields = arg.split("=", 1)
-        if (len(fields) == 2):
+        if len(fields) == 2:
             arg = fields[0]
             val = fields[1]
-            if (val == ""):
+            if val == "":
                 usage("missing a value in %s=" % arg)
 
         if (arg == "--silent") and (val is None):
@@ -68,20 +68,20 @@ def main():
         else:
             usage("unknown argument: %s" % arg)
 
-    if (primary is None):
+    if primary is None:
         usage("missing primary species")
 
-    if (secondary is None):
+    if secondary is None:
         usage("missing secondary species")
 
     fields = primary.split(":")
-    if (len(fields) != 2):
+    if len(fields) != 2:
         usage("bad primary species (must be species:lengths_file")
     primary = fields[0]
     primaryLengths = fields[1]
 
     fields = secondary.split(":")
-    if (len(fields) != 2):
+    if len(fields) != 2:
         usage("bad secondary species (must be species:lengths_file")
     secondary = fields[0]
     secondaryLengths = fields[1]
@@ -103,17 +103,15 @@ def main():
     axtsRead = 0
     axtsWritten = 0
     for axtBlock in bx.align.axt.Reader(
-            sys.stdin,
-            species_to_lengths=speciesToLengths,
-            species1=primary,
-            species2=secondary):
+        sys.stdin, species_to_lengths=speciesToLengths, species1=primary, species2=secondary
+    ):
         axtsRead += 1
 
         p = axtBlock.get_component_by_src_start(primary)
-        if (p is None):
+        if p is None:
             continue
         s = axtBlock.get_component_by_src_start(secondary)
-        if (s is None):
+        if s is None:
             continue
 
         mafBlock = bx.align.Alignment(axtBlock.score, axtBlock.attributes)
@@ -123,7 +121,7 @@ def main():
         out.write(mafBlock)
         axtsWritten += 1
 
-    if (not silent):
+    if not silent:
         sys.stderr.write("%d blocks read, %d written\n" % (axtsRead, axtsWritten))
 
 
@@ -139,13 +137,13 @@ def read_lengths(fileName):
 
     for lineNumber, line in enumerate(f):
         line = line.strip()
-        if (line == ""):
+        if line == "":
             continue
-        if (line.startswith("#")):
+        if line.startswith("#"):
             continue
 
         fields = line.split()
-        if (len(fields) != 2):
+        if len(fields) != 2:
             raise ValueError("bad lengths line (%s:%d): %s" % (fileName, lineNumber, line))
 
         chrom = fields[0]
@@ -154,7 +152,7 @@ def read_lengths(fileName):
         except ValueError:
             raise ValueError("bad lengths line (%s:%d): %s" % (fileName, lineNumber, line))
 
-        if (chrom in chromToLength):
+        if chrom in chromToLength:
             raise ValueError("%s appears more than once (%s:%d): %s" % (chrom, fileName, lineNumber, line))
 
         chromToLength[chrom] = length
