@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 
 """
 Build windows of length `window_size` over the sequences defined by
@@ -12,7 +12,6 @@ between the windows.
 
 usage: %prog len_file gap_file window_size
 """
-from __future__ import print_function
 
 import sys
 
