@@ -19,11 +19,11 @@ def __main__():
         gc = 0
         bases = 0
         for c in m.components:
-            gc += c.text.count('G')
-            gc += c.text.count('C')
-            gc += c.text.count('g')
-            gc += c.text.count('c')
-            bases += (len(c.text) - c.text.count('-'))
+            gc += c.text.count("G")
+            gc += c.text.count("C")
+            gc += c.text.count("g")
+            gc += c.text.count("c")
+            bases += len(c.text) - c.text.count("-")
 
         print(gc / bases)
 
