@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 Read a PAIRWISE maf from stdin and print the fraction of columns whose bases
@@ -8,7 +8,6 @@ TODO: generalize for more than two speceis.
 
 usage: %prog < maf > out
 """
-from __future__ import division, print_function
 
 import sys
 
